==============
Administration
==============

The GraphDb plugin stores a graph model with vertices and edges.

This is ideal for representing an IT network, Power network, Gas network, or any network
that has a topology.


`See Graph Theory at Wikipedia <https://en.wikipedia.org/wiki/Graph_(discrete_mathematics)>`_

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    overview
    status/status
    admin_tasks
    trace_logic
